# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Anonymous = object
Any = object
BoundMethodWeakref = object
DispatcherError = object
Parameter = object
_call = dummy_function
_cleanupConnections = dummy_function
_removeReceiver = dummy_function
_removeSender = dummy_function
connect = dummy_function
connections = dict()
disconnect = dummy_function
safeRef = dummy_function
send = dummy_function
senders = dict()
