# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DialogResults = object
EditWindow = object
Editor = object
EditorFrame = object
EditorNotebook = object
EditorNotebookFrame = object
EditorShellNotebook = object
EditorShellNotebookFrame = object
Shell = object
directory = dummy_function
fileDialog = dummy_function
messageDialog = dummy_function
openMultiple = dummy_function
openSingle = dummy_function
saveSingle = dummy_function
