# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


HTTPError = object
URLError = object
download_file = dummy_function
download_pip = dummy_function
download_urllib = dummy_function
download_wget = dummy_function
get_docs_demo_url = dummy_function
get_save_path = dummy_function
main = dummy_function
