# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DISPLAY_TEXT = ''
GROUPING_END = 0
GROUPING_MASK = 0
GROUPING_MIDDLE = 0
GROUPING_SELECTING = 0
GROUPING_START = 0
GROUPING_START_FOLDED = 0
HELP_TEXT = ''
INPUT_END = 0
INPUT_MASK = 0
INPUT_MIDDLE = 0
INPUT_READLINE = 0
INPUT_START = 0
INPUT_START_FOLDED = 0
IO_ANY_START_MASK = 0
IO_END_MASK = 0
IO_MASK = 0
IO_MIDDLE_MASK = 0
IO_SELECTING = 0
IO_START_FOLDED_MASK = 0
IO_START_MASK = 0
NAVKEYS = tuple()
OUTPUT_BG = 0
OUTPUT_END = 0
OUTPUT_MASK = 0
OUTPUT_MIDDLE = 0
OUTPUT_START = 0
OUTPUT_START_FOLDED = 0
PRINT_UPDATE_MAX_TIME = 0
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
READLINE_BG = 0
SlicesShell = object
SlicesShellFacade = object
SlicesShellFrame = object
VERSION = ''
cd = dummy_function
cmp_to_key = dummy_function
groupingStartText = ''
inputStartText = ''
ls = dummy_function
magic = dummy_function
outputStartText = ''
pwd = dummy_function
pyslicesFormatHeaderText = []
sx = dummy_function
testForContinuations = dummy_function
tutorialText = ''
usrBinEnvPythonText = ''
