# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Calltip = object
Crust = object
CrustFrame = object
DispatcherListing = object
Display = object
Filling = object
SessionListing = object
Shell = object
VERSION = ''
