# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DEFAULT_IMGNAME = ''
DEFAULT_MASKCLR = None
app = None
b64encode = dummy_function
convert = dummy_function
img2py = dummy_function
main = dummy_function
