# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_ETC_LAYOUT_NEEDED = object
ExpandoTextCtrl = object
wxEVT_ETC_LAYOUT_NEEDED = 0
